PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Rasterizer.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Macros
Rasterizer.hpp File Reference
`#include "UniformGrid25.hpp"`
`#include "AShape.hpp"`

Go to the source code of this file.

## Data Structures
struct | IndexRange
class | BaseROP
class | RecordRangesROP
class | Rasterizer< ROP >

## Macros
#define | RASTERIZE_CAPS_MASK_SOURCE 0x1
#define | RASTERIZE_CAPS_MASK_TARGET 0x2
#define | RASTERIZE_CAPS_MASK_BOTH (RASTERIZE_CAPS_MASK_SOURCE | RASTERIZE_CAPS_MASK_TARGET)
#define | RASTERIZE_MASK_SEGMENTS 0x1
#define | RASTERIZE_MASK_VIAS 0x2
#define | RASTERIZE_MASK_CAPS 0x4
#define | RASTERIZE_MASK_JUNCTIONS 0x8
#define | RASTERIZE_MASK_ALL 0xf
#define | RASTERIZE_MASK_CAPS_AND_JUNCTIONS (RASTERIZE_MASK_CAPS | RASTERIZE_MASK_JUNCTIONS)

## Macro Definition Documentation

## ◆ RASTERIZE_CAPS_MASK_BOTH

#define RASTERIZE_CAPS_MASK_BOTH (RASTERIZE_CAPS_MASK_SOURCE | RASTERIZE_CAPS_MASK_TARGET)

## ◆ RASTERIZE_CAPS_MASK_SOURCE

#define RASTERIZE_CAPS_MASK_SOURCE 0x1

This is generic rasterization code that works for any class derived from UniformGrid25. Transforms shapes to the set of grid indices they cover. All you need to do is implement the rasterizatin operation and pass it as a template parameter to the rasterizer (for speed purposes). You can also use RecordRangesROP implemented here to simply get the index ranges back.

## ◆ RASTERIZE_CAPS_MASK_TARGET

#define RASTERIZE_CAPS_MASK_TARGET 0x2

## ◆ RASTERIZE_MASK_ALL

#define RASTERIZE_MASK_ALL 0xf

## ◆ RASTERIZE_MASK_CAPS

#define RASTERIZE_MASK_CAPS 0x4

## ◆ RASTERIZE_MASK_CAPS_AND_JUNCTIONS

#define RASTERIZE_MASK_CAPS_AND_JUNCTIONS (RASTERIZE_MASK_CAPS | RASTERIZE_MASK_JUNCTIONS)

## ◆ RASTERIZE_MASK_JUNCTIONS

#define RASTERIZE_MASK_JUNCTIONS 0x8

## ◆ RASTERIZE_MASK_SEGMENTS

#define RASTERIZE_MASK_SEGMENTS 0x1

## ◆ RASTERIZE_MASK_VIAS

#define RASTERIZE_MASK_VIAS 0x2